# Copyright 2012-2020 James Geboski <jgeboski@gmail.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# Image origin: http://en.wikipedia.org/wiki/File:DIN_4844-2_Warnung_vor_einer_Gefahrenstelle_D-W000.svg

CAUTION_BASE64 = (
    "iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAABhWlDQ1BJQ0MgcHJvZmlsZQAA"
    "KJF9kT1Iw1AUhU/TSkUqgnYQ6ZChOlkQFXGUKhbBQmkrtOpg8tI/aNKQpLg4Cq4FB38Wqw4u"
    "zro6uAqC4A+Ik6OToouUeF9SaBHjhcf7OO+ew3v3AUKzylQzMAGommWkE3Exl18Vg68IQIAP"
    "g4hIzNSTmcUsPOvrnjqp7mI8y7vvz+pXCiYDfCLxHNMNi3iDeGbT0jnvE4dZWVKIz4nHDbog"
    "8SPXZZffOJccFnhm2Mim54nDxGKpi+UuZmVDJZ4mjiqqRvlCzmWF8xZntVpn7XvyF4YK2kqG"
    "67QiSGAJSaQgQkYdFVRhIUa7RoqJNJ3HPfwjjj9FLplcFTByLKAGFZLjB/+D37M1i1OTblIo"
    "DvS82PbHKBDcBVoN2/4+tu3WCeB/Bq60jr/WBGY/SW90tOgRMLANXFx3NHkPuNwBhp90yZAc"
    "yU9LKBaB9zP6pjwwdAv0rblza5/j9AHI0qyWb4CDQ2CsRNnrHu/u7Z7bvz3t+f0ADmVyf6Xa"
    "xBUAAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAADdcAAA3XAUIom3gAAAkhSURBVHja7Zp7"
    "UNTlGsc/v92FXdiLAnFZsFIhRVBLRJ1Ip1LqTOQ00JidGpt0OlNNauOQlxDIKwaGVo7aaepM"
    "lzOT1tgflqnjMc/p5GEyTYsYNRXD4GgowrLCAnJ5zh8L+2PPcl0WQ+SZef94n/f9vb/3+32e"
    "9/I8vx8MyZAMyZD8ASLCS9XVXLTZKBNh8a0GPm3/fkSvd5a9exERHrhVwPvX1lJ8550IOEtU"
    "FGK3UyiC9lYgYPmqVSr4tpKdjYjw4mAHH1ZSgt1o9CTAYECKi6kSIWQwE/C3uXNV0BqNs7TV"
    "58xBRNgyWMFPOnyYZkVRAc+fHygL5ge6ecKhQzSLMGHQEdDUxDeJiSpQs1mRX8+Hy28XwmWY"
    "RXHp4+OR69c5NNis/9S777qv+Q05FqlzWKXOYZXXN1jc2t55BxEhdbCAD6iq4reICBXg6NFa"
    "sVVFuAiotkXImDE6V3twMFJeTokIhsFAwOr0dHfr79oV5ALfVj7/PNitz5IliAgrb3bwI86c"
    "waHXq8BmztR7gG8rf3pY7+qn0yGFhdSJcMfNTMCOlBTcQB07FtopAT+eCBU/P7V/cjIiwt9v"
    "VvBJBw7Q0t6tFy0ydgq+rSxebHRbCl9+SYsIM2428JqGBo6OHasCCQrSyH/LwrsloPz3CAkP"
    "17iei45GHA6Oi6Dpj7lq+omDBVu3kvjLL6pizRozwcHdv85iUcjKMrvqxcWwbRuTgPn9MVGl"
    "H6xvLi/nbGws4TabUxc3TseRI6HodD0bo6UFps+o4MSJRgDMZjh1ioqoKGIUheqB7gHZ2dkq"
    "eICNGy09Bg+g0cCmfAtKq3muXYPVq7kNyBroaz/6+HEatFp17aelGTzWuaPWKlu3DpMnngiQ"
    "OXMCZOvWYeKo9dwPHn/c4BY4HTnCdRHGDmQCdt9/f/sQV5FTJ8PcQNmrrZKSYvAIhx95RC/2"
    "ancCzp4Jk8BANU5ISkJaWjgwUMHP2rnTHVRGhsnDquvXmz3At5X1680e/VeuNLn12bEDESFl"
    "oIHX1dRQNHKkOtHISK1UXInwADR5sl+nBEye7OfRv/JqhNxxh9bVZ8QIxG6nWAT9QNoEX8rP"
    "J76kRFXkrDdjNHoeMjabdDpIVZVnW0CAwto16rFYVgabNjEaWDRQrB904QKV7dNc06b5d7ip"
    "1TmsMmVK5x6QmOjX4TOOWqvcd5+/q19AAHL+PDUiWAeCB6x79VWCamvVIyz/DfUI+3/p6jLU"
    "WZuiOI9FTWtzXR1kZGAE1v2hBIgQV1DAizt3qrp58wJJTPTr9JmQLgjoqu3uu/145plAV/3T"
    "T+Gbb1ggwtQ/jIDmZrYsWYJWWpeu2aywZrW5y2eCQzRetQGsW2tmmEV1rSVL0DQ18ZaI9zda"
    "TR+sn/bhh8w6elTVvbrCRERE10MGe+kBAKGhGlasUAn+8Uf44APuBZ66oQSI4F9dzRvZ2apu"
    "9GgtCxcau302JFjpgpzuDblwYSB33aXeq7OyoLKSfBGMN9ID0nNyiL50SVXk5VnQ67sHENKF"
    "m4eEdD8df3+F119XveDyZdiwASuw/IYQIEL42bNkbmn3+eLBB/XMfrRn+cvgPhIA8GiKgYcf"
    "Uu9BW7bA6dMsF2HkjfCA3PR0TA0NzopO54z2eiohXhyDHUlengW/1sOmsRGWLsUA5PUrASIk"
    "HDzIs3v2qLoXnjcyPr7nsa7Vqu30jhAe3vPpxMbqeOF5ddl/9RXs28fc3n5mV3oBXmls5N8J"
    "CUwvKnLqgoI0FP0c2ivLiUCEtRy7vcU9E2RWuHQpwnXZ6YnYbC2Mn3CFq1edY8XEQFERhXo9"
    "CYpCs6894Olt21TwAKtWmXsFvu1W19FaDw7R9go8wPDhGl57Td0Qz52D7duZCPzFpx4gQkBF"
    "BWdiYxlx9ap3aa72Mn1GBT/80OimS0jw4z+Hb/PmMkZSUgWFPze25hTh1ClskZFEKwqVvvKA"
    "jOxsFbw3aa72EhXl+SNIZKR3P4dotfDmm2rsYbfD2rUM72n6TNMD699eVMSy999XdampBmbN"
    "8j4cjx3rydy4WJ3X4yUl+ZOaqh7D770Hx47xsgjxvvCA/PR0DE1Nzoper7B+nblPEdi99/p3"
    "CKIvsjHPQmCg0w1aWqA1RnmrWw/qxvr37dpFfm6uulcsXWri8bSAPk02JkZHeJgGrQ7GjNGx"
    "cKGRJ5/s25gWi4b6euHw4esAlJZCfDyjP/uMY2vWcLbXm6AIGoeDo+PHk/Drr+o5XfhTGBaL"
    "zz8n+EQcDuGeSVcoLXWegLffDidPUmwyEa8oNPR2CTy3ebMKHmBDjsWn4EWcxVcSGOgejpeW"
    "wubNRHeVPlM6mZi5tJTiuDhCa2qcuqlT/fjXP2/r9BbXGykpaWbZcjuHDjmNMnOmno15FkaN"
    "0vqE1OSHrlJQcL01pwgnT1I7ciQxisLvPfWAVRkZKnhFgfw3hvkEfFlZM9NnVLBnTz0Oh+Bw"
    "CHv21DN9RgVlZc19Hr+j9FlmJkZgbY+WgAgxBQW8/Mkn7dNcAUyZ4ucTN83Kvua6uraXysoW"
    "MrOu+eQd99zjx7x5avpsxw749lueEyGx2yXQ1MRXSUmkfP+9s24yKRT+FIrV6pu/WKNjLnPx"
    "YnOngdL54jCfvOfy5RYmTrxMtd25yUyaBEePUqDVMr31Vz1PDxAh+eOPVfAAK5abfAbemdDw"
    "rq23EhamYdkyk6t+4gR89BFJwNwOl4AIOpuNtzMz1cZRo7QsWmTElzJ7tsGrNm9k8WKjW/os"
    "IwOqqtjcPn3W3gMW5eYS55bmyrVgMPj2zM/KNBM3zvPaGzdOR3aW2afv8vdXyMlxT5/l5hIJ"
    "LHXbA0QIPneO4vHjGd6W6XngAX/27e2f/5ZraoRNm2o5+HU9AMmzDLzyihGTqX8uWI89Vsk/"
    "Dja4lllhIfVjxxKrKFxoI+Cd1FRe3L1bjbC++y60V5megSynTzcxddoVGhvbCIHdu9mhKDyt"
    "E2Hi11/zfBt4gIeS9TReF9cvKoNBkmfp2bff6QVffAH79/NnEbYjwoEJE+j0g+VgLfHxiAhH"
    "lPJy6sPDffOt/WaTS5eoRYS9aWm3ngekpiIifKaIEAr89eJFZjsc1N0Klg8IgKgojgDPMiRD"
    "MiS3tPwPyDEn525xOZcAAAAASUVORK5CYII="
)
